@@ -28,6 +28,12 @@ class TechStack(Utils, Meta):
         logger.remove()
         logger.add(sys.stderr, format="{level:<10} {time} {message}", level=logLevel, colorize=True)
 
+        if os.name == 'nt': 
+            logger.debug('Dectected Windows, enabling pyperclip')
+        else:
+            logger.debug(f"Dectected platform: {os.name}")
+
+
         if password == None:
             password = getpass.getpass('Enter password: ')
 
@@ -58,7 +64,7 @@ class TechStack(Utils, Meta):
         try:
             response =  json.loads(response.text)
             token = response['access_token']
-            logger.debug(f"Token: {token[:10]}")
+            logger.debug(f"Got Token: {token[:10]}...")
         except:
             logger.error(response)
 
